@@ -1,5 +1,5 @@
 __title__ = 'embedly-cards'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __author__ = 'Josh Izaac'
 __credits__ = ["Josh Izaac", ]
 __maintainer__ = "Josh Izaac"
@@ -8,4 +8,5 @@ __status__ = "Stable"
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014'
 
-from embedly_cards.card import register
+from embedly_cards.card_rst import register
+from embedly_cards.card_markdown import EmbedlyCardExtension
